# About gold-miner

The `gold-miner` tool suite applies a simple statistical analysis of
labeled traffic samples to produce a profile which can then be used to
fingerprint an unknown traffic sample with a goal of rapidly
identifying its contents without requiring deep packet inspection.
Specifically, `gold-miner` is designed to prioritize calculation speed
over higher levels of accuracy that more complex analysis techniques
may produce.

# Documentation

See the [documentation] for full details about how to `install` and
`use` the gold-miner package(s).

[documentation]: https://gold-miner.readthedocs.io/en/latest/

# See also

The `gold-miner-ui` package contains add-on modules which require a
more extensive list of python pre-requisites but contain more powerful
tools, such as `gold-miner-tande`.
